@@ -5,9 +5,8 @@ public class A3BackgroundTest {
         A3Window w = new A3Window(300,300);
         w.setNavigationMode(A3CanvasInterface.NaviMode.EXAMINE);
         //A3Background b = new A3Background();
-        A3Background b = new A3Background(1.0f,0.5f,0.0f);
-        //A3Background b = new A3Background("file:///home/ksaito/media/A3/background0/background0.wrl");
-        //A3Background b = new A3Background("file:///home/ksaito/media/A3/canoma/paris/paris.wrl");
+        //A3Background b = new A3Background(1.0f,0.5f,0.0f);
+        A3Background b = new A3Background("x-res:///image.gif");
         w.setBackground(b);
         Action3D a3 = new Action3D("x-res:///axis.a3");
         w.add(a3);
