@@ -5,7 +5,7 @@ public class A3Sound {
         //jp.sourceforge.acerola3d.A23.initA23();
         A3Window window = new A3Window(300,300);
         Action3D a3 = Action3D.load("x-res:///dog_cat.a3");
-        a3.change(1);
+        a3.changeImmediately(1);
         window.add(a3);
 
         double t=0.0;
