@@ -13,6 +13,7 @@ class A3Behavior extends Behavior {
     A3VirtualUniverse universe = null;
     boolean isInterpolate = false;
     boolean autoDirectionControl = false;
+    boolean billboardControl = false;
     double nextS = 1.0;
     Quat4d nextQ = new Quat4d(0.0,0.0,0.0,1.0);
     Vector3d nextV = new Vector3d();
@@ -75,6 +76,8 @@ class A3Behavior extends Behavior {
         nowV.add(nowTrans);
         if (autoDirectionControl) {
             autoQuatControl();
+        } else if (billboardControl) {
+            billboardControl();
         } else {
             nowQ.normalize();
             nowQ.interpolate(nextQ,0.2);
@@ -141,7 +144,7 @@ class A3Behavior extends Behavior {
             m.m10 = -newRight.y;m.m11 = newTop.y;m.m12 = newFront.y;
             m.m20 = -newRight.z;m.m21 = newTop.z;m.m22 = newFront.z;
             m.get(nowQ);
-        }        
+        }
     }
     void autoQuatControlZ() {
         Vector3d dv = new Vector3d(); 
@@ -179,13 +182,105 @@ class A3Behavior extends Behavior {
             m.m10 = -newRight.y;m.m11 = -newFront.y;m.m12 = newTop.y;
             m.m20 = -newRight.z;m.m21 = -newFront.z;m.m22 = newTop.z;
             m.get(nowQ);
-        }        
+        }
+    }
+    void billboardControl() {
+        if (universe!=null) {
+            if (universe.scene.upperDirection==A3Object.UpperDirection.Z) {
+                billboardControlZ();
+                return;
+            }
+        }
+        billboardControlY();
+    }
+    void billboardControlY() {
+        Vector3d dv = new Vector3d(); 
+        dv.sub(universe.scene.cameraNowV,nowV);
+        if (dv.length()>universe.scene.cameraNowS/1000.0) {
+            Vector3d upperVector = new Vector3d(a3.upperVector);
+            upperVector.normalize();
+
+            Vector3d newFront = new Vector3d(dv);
+            newFront.normalize();
+            //なぜかm.get(nowQ)が上手くいかないときがある。
+            //原因はよくわかってない。しょうがないので強引に
+            //以下のif文を入れる。
+            if ((Math.abs(newFront.x)<0.0001)&&(newFront.z<0.0)) {
+                newFront.x=0.0001;
+                newFront.normalize();
+            }
+            double d = newFront.dot(upperVector);
+            Vector3d vTmp = new Vector3d(newFront);
+            vTmp.scale(d);
+            Vector3d newTop = new Vector3d(upperVector);
+            newTop.sub(vTmp);
+            if (newTop.lengthSquared()<0.00001) {
+                //この場合とりあえず適当
+                newFront.set(0.0,0.0,1.0);
+                newTop.set(0.0,1.0,0.0);
+            } else {
+                newTop.normalize();
+            }
+            Vector3d newRight = new Vector3d();
+            newRight.cross(newFront,newTop);
+
+            Matrix4d m = new Matrix4d();
+            m.m00 = -newRight.x;m.m01 = newTop.x;m.m02 = newFront.x;
+            m.m10 = -newRight.y;m.m11 = newTop.y;m.m12 = newFront.y;
+            m.m20 = -newRight.z;m.m21 = newTop.z;m.m22 = newFront.z;
+            m.get(nowQ);
+        }
+    }
+    void billboardControlZ() {
+        Vector3d dv = new Vector3d(); 
+        dv.sub(universe.scene.cameraNowV,nowV);
+        if (dv.length()>universe.scene.cameraNowS/1000.0) {
+            Vector3d upperVector = new Vector3d(a3.upperVector);
+            upperVector.normalize();
+
+            Vector3d newFront = new Vector3d(dv);
+            newFront.normalize();
+            //なぜかm.get(nowQ)が上手くいかないときがある。
+            //原因はよくわかってない。しょうがないので強引に
+            //以下のif文を入れる。
+            if ((Math.abs(newFront.x)<0.0001)&&(newFront.y>0.0)) {
+                newFront.x=0.0001;
+                newFront.normalize();
+            }
+            double d = newFront.dot(upperVector);
+            Vector3d vTmp = new Vector3d(newFront);
+            vTmp.scale(d);
+            Vector3d newTop = new Vector3d(upperVector);
+            newTop.sub(vTmp);
+            if (newTop.lengthSquared()<0.00001) {
+                //この場合とりあえず適当
+                newFront.set(0.0,-1.0,0.0);
+                newTop.set(0.0,0.0,1.0);
+            } else {
+                newTop.normalize();
+            }
+            Vector3d newRight = new Vector3d();
+            newRight.cross(newFront,newTop);
+
+            Matrix4d m = new Matrix4d();
+            m.m00 = -newRight.x;m.m01 = -newFront.x;m.m02 = newTop.x;
+            m.m10 = -newRight.y;m.m11 = -newFront.y;m.m12 = newTop.y;
+            m.m20 = -newRight.z;m.m21 = -newFront.z;m.m22 = newTop.z;
+            m.get(nowQ);
+        }
     }
     void setEnableBehavior(boolean b) {
         isInterpolate = b;
     }
     void setAutoDirectionControl(boolean b) {
         autoDirectionControl = b;
+        if (autoDirectionControl&&billboardControl)
+            billboardControl=false;
+    }
+    void setBillboardControl(boolean b) {
+        billboardControl = b;
+        if (billboardControl&&autoDirectionControl)
+            autoDirectionControl=false;
     }
     void move(Vector3d v, Quat4d q, double s) {
         if (isInterpolate) {
