@@ -87,6 +87,14 @@ public abstract class A3Object {
         behavior.setAutoDirectionControl(b);
     }
 
+    /**
+     * これを有効にするとカメラに対して常に正面を向くように
+     * 回転を自動的に補正します。
+     */
+    public final void setBillboardControl(boolean b) {
+        behavior.setBillboardControl(b);
+    }
+
     /**
      * このオブジェクトの上方向を設定します。この上方向とは、
      * A3Objectのオートコントロール機能における正面の計算で、
