@@ -54,7 +54,7 @@ public class Action3D extends A3Object implements ActionObject {
 
     /**
      * A3InitDataをもとにAction3Dオブジェクトを生成するコンストラクタ。
-     * A3InitDataの引数の数は、2か5か7でなければなりません。
+     * A3InitDataの引数の数は、2か5か7か8でなければなりません。
      * 引数が5か7の時は自動的にautoActionControl=trueとなります。
      *
      * <table border="1">
@@ -65,6 +65,7 @@ public class Action3D extends A3Object implements ActionObject {
      * <tr><td>4:Serializable</td><td>runActionID     </td><td>任意</td></tr>
      * <tr><td>5:double      </td><td>walkSpeed       </td><td>任意</td></tr>
      * <tr><td>6:double      </td><td>runSpeed        </td><td>任意</td></tr>
+     * <tr><td>7:boolean     </td><td>billboard       </td><td>任意</td></tr>
      * </table>
      */
     public Action3D(A3InitData d) throws Exception {
@@ -109,6 +110,10 @@ public class Action3D extends A3Object implements ActionObject {
             action3DData = new Action3DData(url);
             action3DDataCash.put(url,action3DData);
         }
+        if (action3DData.billboardControl) {
+            setEnableBehavior(true);
+            setBillboardControl(true);
+        }
         actionBehavior = new ActionBehavior(this,action3DData.copy()); 
         setNode(actionBehavior.getNode());
 
@@ -123,6 +128,9 @@ public class Action3D extends A3Object implements ActionObject {
             setMinWalkSpeed(d.getDouble(5));
             setMinRunSpeed(d.getDouble(6));
         }
+        if (d.getDataCount()>=8) {
+            setBillboardControl(d.getBoolean(7));
+        }
     }
 
     protected void init() {
