@@ -68,6 +68,7 @@ class Action3DData {
     double minWalkSpeed = 0.1;
     double minRunSpeed = 1.0;
     boolean autoActionControl = false;
+    boolean billboardControl = false;
     String rdf;
     String tags[];
     String profiles[];
@@ -498,6 +499,7 @@ class Action3DData {
         ret.minWalkSpeed = minWalkSpeed;
         ret.minRunSpeed = minRunSpeed;
         ret.autoActionControl = autoActionControl;
+        ret.billboardControl = billboardControl;
         ret.rdf = rdf;
         ret.tags = tags.clone();
         ret.profiles = profiles.clone();
@@ -559,6 +561,7 @@ class Action3DData {
         runActionNo = a3.getRunActionNo().intValue();
         minWalkSpeed = a3.getMinWalkSpeed();
         minRunSpeed = a3.getMinRunSpeed();
+        billboardControl = a3.isBillboard();
         comment = a3.getC();
         actions = new Action[a3.getA().size()];
         actionNames = new String[a3.getA().size()];
@@ -757,6 +760,9 @@ class Action3DData {
         attr = (Attr)nnm.getNamedItem("autoActionControl");
         if (attr!=null)
             autoActionControl = Boolean.parseBoolean(attr.getValue().trim());
+        attr = (Attr)nnm.getNamedItem("billboard");
+        if (attr!=null)
+            billboardControl = Boolean.parseBoolean(attr.getValue().trim());
         
         //コメントデータゲット
         org.w3c.dom.Node cc[] = xpath("/a3/c/text()",d);
@@ -1129,6 +1135,12 @@ class Action3DData {
     double getMinRunSpeed() {
         return minRunSpeed;
     }
+    void setBillboardControl(boolean b) {
+        billboardControl = b;
+    }
+    boolean getBillboardControl() {
+        return billboardControl;
+    }
     //------------------------------------------------------------
     void setShape(int actionNo,String boneName,Node shape) {
         Part p = actions[actionNo].pHash.get(boneName);
