@@ -125,9 +125,10 @@ class ActionBehavior extends Behavior implements Cloneable {
     public void initialize() {
         if (elapsedTime==0) //<-- なんでこれが必要なのか
             return;         //<-- わからない
-        WakeupOnElapsedTime w = new WakeupOnElapsedTime(elapsedTime);
-        wakeupOn(w);
+        //WakeupOnElapsedTime w = new WakeupOnElapsedTime(elapsedTime);
+        //wakeupOn(w);
         timeOffset = System.currentTimeMillis();
+        processStimulus(null);
     }
     @SuppressWarnings("unchecked")
     public void processStimulus(Enumeration criteria) {
@@ -222,7 +223,7 @@ class ActionBehavior extends Behavior implements Cloneable {
 
             //再生後初めてのサウンド再生
             //((newPlayStatus==4)&&(playStatus==0))==trueのような場合も再生する
-            if ((newPlayStatus>=S2)&&(playStatus<=S2)) {
+            if ((newPlayStatus>=S2)&&(playStatus<S2)) {
                 if (a3Data.actions[actionNo].sound!=null) {
                     //a3Data.actions[actionNo].sound.setEnable(false);
                     a3Data.actions[actionNo].sound.setEnable(true);
